==> xlr-application-pipelines-module-24.3.0-rc.1.jar: web/include/external-deployments/components/external-deployment-component.portal.tsx <==
import React from 'react';
import { DotButton, DotIcon } from '@digital-ai/dot-components';
import { ActionToolbarPortalContainer } from '../../../../../../../../../core/xlr-ui/app/features/main-navigation/action-toolbar/components/action-toolbar.portal';
import { Folder } from '../../../../../../../../../core/xlr-ui/app/types';
import { useAppDispatch } from '../../../../../../../../../core/xlr-ui/app/js/hooks';
import { folderExternalDeployments } from '../ducks/external-deployments.reducer';
import { folderDeploymentServers } from '../../deployment-server/ducks/deployment-server.reducer';

export interface ApplicationsTableComponentPortalProp {
    folder: Folder;
    reSyncEnabled: boolean;
}

const { refreshExternalDeployments } = folderExternalDeployments.actions;
const { openLiveDeploymentConfiguration } = folderDeploymentServers.actions;
export const ExternalDeploymentComponentPortal = (props: ApplicationsTableComponentPortalProp) => {
    const { reSyncEnabled } = props;

    const dispatch = useAppDispatch();

    return (
        <ActionToolbarPortalContainer>
            <DotButton disabled={!reSyncEnabled} onClick={() => dispatch(refreshExternalDeployments())} startIcon={<DotIcon iconId="sync" />} type="outlined">
                Re-sync
            </DotButton>
            <DotButton
                onClick={() => {
                    dispatch(openLiveDeploymentConfiguration(false));
                }}
                type="primary"
            >
                Configure
            </DotButton>
        </ActionToolbarPortalContainer>
    );
};

==> xlr-application-pipelines-module-24.3.12-1102.130.jar: web/include/external-deployments/components/external-deployment-component.portal.tsx <==
import React from 'react';
import { DotButton, DotIcon } from '@digital-ai/dot-components';
import { ActionToolbarPortalContainer } from '../../../../../../../../../core/xlr-ui/app/features/main-navigation/action-toolbar/components/action-toolbar.portal';
import { Folder } from '../../../../../../../../../core/xlr-ui/app/types';
import { useAppDispatch } from '../../../../../../../../../core/xlr-ui/app/js/hooks';
import { folderExternalDeployments } from '../ducks/external-deployments.reducer';
import { folderDeploymentServers } from '../../deployment-server/ducks/deployment-server.reducer';

export interface ApplicationsTableComponentPortalProp {
    folder: Folder;
    reSyncEnabled: boolean;
}

const { refreshExternalDeployments } = folderExternalDeployments.actions;
const { openLiveDeploymentConfiguration } = folderDeploymentServers.actions;
export const ExternalDeploymentComponentPortal = (props: ApplicationsTableComponentPortalProp) => {
    const { reSyncEnabled } = props;

    const dispatch = useAppDispatch();

    return (
        <ActionToolbarPortalContainer>
            <DotButton
                className="sync-btn"
                disabled={!reSyncEnabled}
                onClick={() => dispatch(refreshExternalDeployments())}
                startIcon={<DotIcon iconId="sync" />}
                type="outlined"
            >
                Refresh
            </DotButton>
            <DotButton
                className="conf-btn"
                onClick={() => {
                    dispatch(openLiveDeploymentConfiguration(false));
                }}
                type="primary"
            >
                Configure
            </DotButton>
        </ActionToolbarPortalContainer>
    );
};
